"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const target_protocol_input_component_1 = require("./target-protocol-input-component");
const check_for_docker_component_1 = require("./check-for-docker-component");
const target_config_file_1 = require("../util/target-config-file");
const target_hostname_input_component_1 = require("./target-hostname-input-component");
const target_path_input_component_1 = require("./target-path-input-component");
const write_app_config_file_component_1 = require("./write-app-config-file-component");
const write_app_py_file_component_1 = require("./write-app-py-file-component");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
const constants_1 = require("../constants");
const write_dockerfile_component_1 = require("./write-dockerfile-component");
const DOCKER_IMAGE_ID_INITIAL_VALUE = `${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}:${constants_1.DOCKER_FALLBACK_TAG_NAME}`;
async function appConfigureComponent(props) {
    const { yes } = props;
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    await write_app_config_file_component_1.writeAppConfigFileComponent({ yes });
    await write_app_py_file_component_1.writeAppPyFileComponent();
    await write_dockerfile_component_1.writeDockerfileComponent();
    const targetProtocol = yes
        ? props.targetProtocol
        : await target_protocol_input_component_1.targetProtocolPromptedInputComponent({
            targetProtocol: props.targetProtocol,
        });
    switch (targetProtocol) {
        case 'docker:':
            await check_for_docker_component_1.checkForDockerComponent();
            target_config_file_1.targetConfigFile.write({
                targetProtocol,
                dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
            });
            ora(`Write ${target_config_file_1.TARGET_CONFIG_FILE_NAME}`).succeed();
            break;
        case 'ssh+docker:':
            const targetHostname = yes
                ? props.targetHostname
                : await target_hostname_input_component_1.targetHostnameInputComponent({
                    yes,
                    targetHostname: props.targetHostname,
                });
            await check_for_docker_component_1.checkForDockerComponent({ targetHostname });
            const targetPath = await target_path_input_component_1.targetPathInputComponent({
                yes,
                targetHostname,
                targetPath: props.targetPath,
            });
            target_config_file_1.targetConfigFile.write({
                targetProtocol,
                targetHostname,
                targetPath,
                dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
            });
            ora(`Write ${target_config_file_1.TARGET_CONFIG_FILE_NAME}`).succeed();
            break;
        default:
            throw new Error(`Unexpected target protocol ${targetProtocol}`);
    }
}
exports.appConfigureComponent = appConfigureComponent;
//# sourceMappingURL=app-configure-component.js.map