"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logSymbols = require("log-symbols");
const app_config_file_1 = require("../util/app-config-file");
const target_config_file_1 = require("../util/target-config-file");
const js_spawner_1 = require("../spawner/js-spawner");
const app_installer_1 = require("../app-installer");
const spin_on_promise_1 = require("../util/spin-on-promise");
const echo_1 = require("../util/echo");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
const check_for_required_files_component_1 = require("./check-for-required-files-component");
const cognito_auth_1 = require("../util/cognito-auth");
const build_docker_image_1 = require("../util/build-docker-image");
async function appDeployComponent(props) {
    const { yes } = props;
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    const bearerToken = await cognito_auth_1.getBearerToken();
    if (!bearerToken) {
        throw new Error('Expected to get bearer token');
    }
    await check_for_required_files_component_1.checkForRequiredFilesComponent({ yes });
    const appConfig = app_config_file_1.appConfigFile.read();
    const targetHostSpawner = target_config_file_1.targetConfigFile.readHostSpawner();
    const targetConfig = target_config_file_1.targetConfigFile.read();
    const sourceSpawner = js_spawner_1.JsSpawner();
    await spin_on_promise_1.spinOnPromise(targetHostSpawner.mkdirp(), 'Create target directory');
    const hostAppInstaller = app_installer_1.AppInstaller(targetHostSpawner, bearerToken);
    // Protocol-specific installation steps
    switch (targetConfig.targetProtocol) {
        case 'ssh+docker:': {
            await spin_on_promise_1.spinOnPromise(hostAppInstaller.installSource(sourceSpawner), 'Copy application to target');
        }
    }
    let hasModels = false;
    if (appConfig.models) {
        const ids = Object.keys(appConfig.models);
        if (ids.length > 0) {
            hasModels = true;
            await spin_on_promise_1.spinOnPromise(hostAppInstaller.installModels(appConfig.models), `Model${ids.length > 1 ? 's' : ''} ${ids.join(' ')}`);
        }
    }
    if (!hasModels) {
        echo_1.echo(`${logSymbols.warning} Application has no models`);
    }
    const dockerImageId = await spin_on_promise_1.spinOnPromise(build_docker_image_1.buildDockerImage(targetHostSpawner), 'Build docker image');
    target_config_file_1.targetConfigFile.update(targetConfiguration => {
        targetConfiguration.dockerImageId = dockerImageId;
    });
    const targetSpawner = target_config_file_1.targetConfigFile.readContainerSpawner();
    const targetAppInstaller = app_installer_1.AppInstaller(targetSpawner, bearerToken);
    await spin_on_promise_1.spinOnPromise(targetAppInstaller.installVirtualenv(), 'Install python virtualenv');
    await spin_on_promise_1.spinOnPromise(targetAppInstaller.installPythonDeps(), 'Install python dependencies');
}
exports.appDeployComponent = appDeployComponent;
//# sourceMappingURL=app-deploy-component.js.map