"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const ora = require("ora");
const constants_1 = require("../constants");
const semver_1 = require("semver");
const download = require("download");
async function writeDockerfileComponent() {
    if (!fs_1.existsSync(constants_1.DOCKERFILE)) {
        const spinner = ora(`Write ${constants_1.DOCKERFILE}`);
        const buffer = await download(`https://registry.hub.docker.com/v1/repositories/${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}/tags`);
        const serialized = buffer.toString('utf8');
        const parsed = JSON.parse(serialized);
        const names = parsed.map(({ name }) => name);
        const semverNames = names.filter(name => Boolean(semver_1.valid(name)));
        const sortedSemverNames = semverNames.sort(semver_1.compare);
        const greatestSemver = sortedSemverNames.slice(-1)[0] || constants_1.DOCKER_FALLBACK_TAG_NAME;
        try {
            fs_1.writeFileSync(constants_1.DOCKERFILE, `FROM ${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}:${greatestSemver}\n`, {
                flag: 'wx',
            });
            spinner.succeed();
        }
        catch (exception) {
            if (exception.code !== 'EEXIST') {
                spinner.fail();
                throw exception;
            }
            spinner.succeed(`Found ${constants_1.DOCKERFILE}`);
        }
    }
    else {
        ora(`Found ${constants_1.DOCKERFILE}`).succeed();
    }
}
exports.writeDockerfileComponent = writeDockerfileComponent;
//# sourceMappingURL=write-dockerfile-component.js.map